#!/usr/bin/env python3


from sat.core.i18n import _
from sat.core.log import getLogger
from sat.tools.common import data_format
from twisted.internet import defer
import datetime
import time
from dateutil import tz

from libervia.server.constants import Const as C

log = getLogger(__name__)


name = "calendar"
access = C.PAGES_ACCESS_PROFILE
template = "calendar/daily.html"


async def prepare_render(self, request):
    profile = self.get_profile(request)
    template_data = request.template_data
    # template_data["url_event_new"] = self.get_sub_page_url(request, "event_new")
    if profile is not None:
        try:
            events = data_format.deserialise(
                await self.host.bridge_call("events_get", "", "", [], "", profile),
                type_check=list
            )
        except Exception as e:
            log.warning(_("Can't get events list for {profile}: {reason}").format(
                profile=profile, reason=e))
        else:
            template_data["events"] = events

    tz_name = template_data["tz_name"] = time.tzname[0]
    local_tz = tz.tzlocal()
    today_local = datetime.datetime.now(local_tz).date()
    calendar_start = template_data["calendar_start"] = datetime.datetime.combine(
        today_local, datetime.time.min, tzinfo=local_tz
    ).timestamp()
    calendar_end = template_data["calendar_end"] = datetime.datetime.combine(
        today_local, datetime.time.max, tzinfo=local_tz
    ).timestamp()
    self.expose_to_scripts(
        request,
        calendar_start=calendar_start,
        calendar_end=calendar_end,
        tz_name=tz_name,
    )
